@@ -5,20 +5,17 @@
 (c) Sam Schott; This work is licensed under a Creative Commons
 Attribution-NonCommercial-NoDerivs 2.0 UK: England & Wales License.
 
-The following APIs should remain stable for front ends:
+The following APIs should remain stable for frontends:
 
 * maestral.main.Maestral
-* maestral.oauth
 * maestral.constants
 * maestral.daemon
 * maestral.errors
-* maestral.config.main
 * maestral.utils.appdirs
-* maestral.utils.backend
 * maestral.utils.autostart
 
 """
 
-__version__ = "0.6.4"
-__author__ = "Sam Schott"
-__url__ = "https://github.com/SamSchott/maestral"
+__version__ = '1.2.0'
+__author__ = 'Sam Schott'
+__url__ = 'https://github.com/SamSchott/maestral'
